@@ -87,4 +87,15 @@ def notime_lab_file(testpath):
 @pytest.fixture
 def multi_run_file(testpath):
     return fetch_file('gvy84', testpath,
-                      'Test2_samefreq_TWOscans.txt')
\ No newline at end of file
+                      'Test2_samefreq_TWOscans.txt')
+
+@pytest.fixture
+def matlab_file_labchart(testpath):
+    return fetch_file('2j43t', testpath,
+                      'test_2minRest.mat')
+
+
+@pytest.fixture
+def matlab_file_acq(testpath):
+    return fetch_file('mc96w', testpath,
+                      'Test_belt_pulse_multifreq.mat')
