@@ -8,7 +8,7 @@ from pathlib import Path
 
 LGR = logging.getLogger(__name__)
 
-SUPPORTED_FTYPES = ('acq', 'txt')  # 'mat', ...
+SUPPORTED_FTYPES = ('acq', 'txt', 'mat')
 
 
 def check_input_dir(indir):
@@ -110,26 +110,6 @@ def check_input_type(filename, indir):
                         f' {", ".join(SUPPORTED_FTYPES)}')
 
 
-def path_exists_or_make_it(fldr):
-    """
-    Check if folder exists, if not make it.
-
-    Parameters
-    ----------
-    fldr: str or path
-        A string representing a folder,
-        or a fullpath to such folder
-
-    Notes
-    -----
-    Outcome:
-    fldr:
-        Creates the fullpath to `fldr` if it doesn't exists.
-    """
-    if not os.path.isdir(fldr):
-        os.makedirs(fldr)
-
-
 def check_file_exists(filename):
     """
     Check if file exists.
@@ -149,35 +129,6 @@ def check_file_exists(filename):
         raise FileNotFoundError(f'The file {filename} does not exist!')
 
 
-def move_file(oldpath, newpath, ext=''):
-    """
-    Move file from oldpath to newpath.
-
-    If file already exists, removes it first.
-
-    Parameters
-    ----------
-    oldpath: str or path
-        A string or a fullpath to a file that has to be moved
-    newpath: str or path
-        A string or a fullpath to the new destination of the file
-    ext: str
-        Possible extension to add to the oldpath and newpath. Not necessary.
-
-    Notes
-    -----
-    Outcome:
-    newpath + ext:
-        Moves file to new destination
-    """
-    check_file_exists(oldpath + ext)
-
-    if os.path.isfile(newpath + ext):
-        os.remove(newpath + ext)
-
-    os.rename(oldpath + ext, newpath + ext)
-
-
 def copy_file(oldpath, newpath, ext=''):
     """
     Copy file from oldpath to newpath.
@@ -209,7 +160,7 @@ def copy_file(oldpath, newpath, ext=''):
     cp(oldpath + ext, newpath + ext)
 
 
-def writefile(filename, ext, text):
+def write_file(filename, ext, text):
     """
     Produce a textfile of the specified extension `ext`.
 
@@ -235,7 +186,7 @@ def writefile(filename, ext, text):
         print(text, file=text_file)
 
 
-def writejson(filename, data, **kwargs):
+def write_json(filename, data, **kwargs):
     """
     Output a json file with the given data inside.
 
